aboutsummaryrefslogtreecommitdiff
path: root/sbin/mount/mount.c
diff options
context:
space:
mode:
authorTom Rhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committerTom Rhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commitce66ddb76352a2e5f34aacdbe7733d92e60aff17 (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/mount/mount.c
parent7d971bbf29d32d2a93e71f178b5e6aa0c544df1c (diff)
downloadsrc-ce66ddb76352a2e5f34aacdbe7733d92e60aff17.tar.gz
src-ce66ddb76352a2e5f34aacdbe7733d92e60aff17.zip
s/filesystem/file system/g as discussed on -developers
Notes
Notes: svn path=/head/; revision=102231
Diffstat (limited to 'sbin/mount/mount.c')
-rw-r--r--sbin/mount/mount.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sbin/mount/mount.c b/sbin/mount/mount.c
index e08202ff8a93..8eff3a8c2b22 100644
--- a/sbin/mount/mount.c
+++ b/sbin/mount/mount.c
@@ -269,10 +269,10 @@ main(argc, argv)
rmslashes(*argv, *argv);
if ((fs = getfsfile(*argv)) == NULL &&
(fs = getfsspec(*argv)) == NULL)
- errx(1, "%s: unknown special file or filesystem",
+ errx(1, "%s: unknown special file or file system",
*argv);
if (BADTYPE(fs->fs_type))
- errx(1, "%s has unknown filesystem type",
+ errx(1, "%s has unknown file system type",
*argv);
rval = mountfs(fs->fs_vfstype, fs->fs_spec, fs->fs_file,
init_flags, options, fs->fs_mntops);
@@ -281,7 +281,7 @@ main(argc, argv)
/*
* If -t flag has not been specified, the path cannot be
* found, spec contains either a ':' or a '@', then assume
* that an NFS filesystem is being specified ala Sun.
* Check if the hostname contains only allowed characters
* to reduce false positives. IPv6 addresses containing
* ':' will be correctly parsed only if the separator is '@'.
@@ -335,7 +335,7 @@ ismounted(fs, mntbuf, mntsize)
int i;
if (fs->fs_file[0] == '/' && fs->fs_file[1] == '\0')
/* the root filesystem can always be remounted */
return (0);
for (i = mntsize - 1; i >= 0; --i)
@@ -281,7 +281,7 @@ main(argc, argv)
* If -t flag has not been specified, the path cannot be
* found, spec contains either a ':' or a '@', then assume
- * that an NFS filesystem is being specified ala Sun.
+ * that an NFS file system is being specified ala Sun.
* Check if the hostname contains only allowed characters
* to reduce false positives. IPv6 addresses containing
@@ -335,7 +335,7 @@ ismounted(fs, mntbuf, mntsize)
int i;
if (fs->fs_file[0] == '/' && fs->fs_file[1] == '\0')
- /* the root filesystem can always be remounted */
+ /* the root file system can always be remounted */
return (0);
for (i = mntsize - 1; i >= 0; --i)